==> eiffelstudio-18.11.10.2592.tar: F_code/C5/kl217.c <==
/*
 * Code for class KL_IMPORTED_ARRAY_ROUTINES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl217.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_IMPORTED_ARRAY_ROUTINES}.integer_array_ */
static EIF_REFERENCE F760_3880_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3880);
#define Result RTOSR(3880)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {924,869,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 924, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3880);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F760_3880 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3880,F760_3880_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.string_array_ */
static EIF_REFERENCE F760_3882_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3882);
#define Result RTOSR(3882)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {922,916,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 922, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3882);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F760_3882 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3882,F760_3882_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.string_array_routines */
static EIF_REFERENCE F760_3883_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3883);
#define Result RTOSR(3883)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {922,916,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 922, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3883);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F760_3883 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3883,F760_3883_body,(Current));
}

void EIF_Minit217 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/kl217.c <==
/*
 * Code for class KL_IMPORTED_ARRAY_ROUTINES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl217.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_IMPORTED_ARRAY_ROUTINES}.integer_array_ */
static EIF_REFERENCE F760_3891_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3891);
#define Result RTOSR(3891)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,923,836,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 923, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3891);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F760_3891 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3891,F760_3891_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.string_array_ */
static EIF_REFERENCE F760_3893_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3893);
#define Result RTOSR(3893)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,922,916,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 922, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3893);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F760_3893 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3893,F760_3893_body,(Current));
}

/* {KL_IMPORTED_ARRAY_ROUTINES}.string_array_routines */
static EIF_REFERENCE F760_3894_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3894);
#define Result RTOSR(3894)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,922,0xFF01,916,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 922, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3894);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F760_3894 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3894,F760_3894_body,(Current));
}

void EIF_Minit217 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
